Details
The default models are naive, ETS, Theta, and ARIMA models. All models are
fitted to log(observation + 1) to stabilise variance in count data.
Forecasts are automatically transformed back to the original scale by
fable. +1 is added to avoid taking the log of zero.
Additional models can be added by extending the returned list, for example:
c(default_models(), list(CUSTOM = fable::ARIMA(observation))).